==> visual-third-party-1.8.5-clip-sources.jar: com/tenqube/visual_third/api/VisualApiService.java <==
package com.tenqube.visual_third.api;

import com.tenqube.visual_third.model.api.AdInfoResponse;
import com.tenqube.visual_third.model.api.AdResponse;
import com.tenqube.visual_third.model.api.CurrencyResponse;
import com.tenqube.visual_third.model.api.SearchCompanyRequest;
import com.tenqube.visual_third.model.api.SearchCompanyResponse;
import com.tenqube.visual_third.model.api.SignUpRequest;
import com.tenqube.visual_third.model.api.SignUpResponse;
import com.tenqube.visual_third.model.api.TransactionRequest;

import retrofit2.Call;
import retrofit2.http.Body;
import retrofit2.http.GET;
import retrofit2.http.Header;
import retrofit2.http.POST;
import retrofit2.http.Path;
import retrofit2.http.Url;

interface VisualApiService {

    String BASE_URL = "https://clip.tenqube.kr/";

    @POST("users/sign-up")
    Call<SignUpResponse> signUp(@Header("x-api-key") String apiKey, @Body SignUpRequest signUp);

    @GET("currency/rate/{from}/{to}")
    Call<CurrencyResponse> callCurrencyRate(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Path("from") String from, @Path("to") String to);

    @POST("transaction")
    Call<Void> saveTransactions(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Body TransactionRequest transactionRequest);

    @POST
    Call<SearchCompanyResponse> searchCompany(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Url String url, @Body SearchCompanyRequest searchCompanyRequest);

    @GET("ad/info")
    Call<AdInfoResponse> getAdInfo(@Header("x-api-key") String apiKey);


    @GET("ad/native/{version}")
    Call<AdResponse> getAds(@Header("x-api-key") String apiKey, @Path("version") int version);
}

==> visual-third-party-2.3.1-clip-sources.jar: com/tenqube/visual_third/api/VisualApiService.java <==
package com.tenqube.visual_third.api;

import com.tenqube.visual_third.model.api.AdInfoResponse;
import com.tenqube.visual_third.model.api.AdResponse;
import com.tenqube.visual_third.model.api.CurrencyResponse;
import com.tenqube.visual_third.model.api.SearchCompanyRequest;
import com.tenqube.visual_third.model.api.SearchCompanyResponse;
import com.tenqube.visual_third.model.api.SignUpRequest;
import com.tenqube.visual_third.model.api.SignUpResponse;
import com.tenqube.visual_third.model.api.TransactionRequest;
import com.tenqube.visual_third.model.api.UserInfoRequest;

import retrofit2.Call;
import retrofit2.http.Body;
import retrofit2.http.GET;
import retrofit2.http.Header;
import retrofit2.http.POST;
import retrofit2.http.Path;
import retrofit2.http.Url;

interface VisualApiService {

    String BASE_URL = "https://clip.tenqube.kr/";

    @POST("users/sign-up")
    Call<SignUpResponse> signUp(@Header("x-api-key") String apiKey, @Body SignUpRequest signUp);

    @POST("users/info")
    Call<Void> saveUserInfo(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Body UserInfoRequest userInfo);

    @GET("currency/rate/{from}/{to}")
    Call<CurrencyResponse> callCurrencyRate(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Path("from") String from, @Path("to") String to);

    @POST("transaction")
    Call<Void> saveTransactions(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Body TransactionRequest transactionRequest);

    @POST
    Call<SearchCompanyResponse> searchCompany(@Header("x-api-key") String apiKey, @Header("Authorization") String authorization, @Url String url, @Body SearchCompanyRequest searchCompanyRequest);

    @GET("ad/info")
    Call<AdInfoResponse> getAdInfo(@Header("x-api-key") String apiKey);

    @GET("ad/native/{version}")
    Call<AdResponse> getAds(@Header("x-api-key") String apiKey, @Path("version") int version);
}
